package Siebel::Srvrmgr::Exporter;

use strict;
use warnings;
our $VERSION = '0.05'; # VERSION

1;
__END__
=head1 NAME

Siebel::Srvrmgr::Exporter - Perl extension for dumping Siebel Components data

=head1 SYNOPSIS

  use Siebel::Srvrmgr::Exporter;

=head1 DESCRIPTION

This module is just Pod and version controlling.

=head2 EXPORT

None by default.

=head1 SEE ALSO

L<Siebel::Srvrmgr>

=head1 AUTHOR

Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>

This file is part of Siebel Monitoring Tools.

Siebel Monitoring Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Siebel Monitoring Tools is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.

=cut

